pub struct KeepAliveC2s(pub i64);Expand description
Sent by the client to the server as a response to the
KeepAliveS2c packet.
The id is the same as the one sent by the server. if a client does not
respond to a KeepAliveS2c packet within 15 seconds, the server should
disconnect the client.
Tuple Fields
0: i64Trait Implementations
Sourceimpl Clone for KeepAliveC2s
impl Clone for KeepAliveC2s
Sourcefn clone(&self) -> KeepAliveC2s
fn clone(&self) -> KeepAliveC2s
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeepAliveC2s
impl Debug for KeepAliveC2s
Sourceimpl<'a> Decode<'a> for KeepAliveC2s
impl<'a> Decode<'a> for KeepAliveC2s
Sourceimpl Encode for KeepAliveC2s
impl Encode for KeepAliveC2s
Sourceimpl Packet for KeepAliveC2s
impl Packet for KeepAliveC2s
Sourceconst SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Serverbound
const SIDE: PacketSide = ::chunkedge_protocol::PacketSide::Serverbound
The side this packet is intended for.
Sourceconst STATE: PacketState = PacketState::Configuration
const STATE: PacketState = PacketState::Configuration
The state in which this packet is used.
impl Copy for KeepAliveC2s